==> lcmaps_1.6.1.orig.tar.gz: lcmaps-1.6.1/interface/lcmaps_db_read.h <==
/**
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010. 
 * See http://www.eu-egee.org/partners/ for details on the copyright
 * holders.  
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 *
 *  Authors:
 *  2009-
 *     Oscar Koeroo <okoeroo@nikhef.nl>
 *     Mischa Sall\'e <msalle@nikhef.nl>
 *     David Groep <davidg@nikhef.nl>
 *     NIKHEF Amsterdam, the Netherlands
 *     <grid-mw-security@nikhef.nl> 
 *
 *  2007-2009
 *     Oscar Koeroo <okoeroo@nikhef.nl>
 *     David Groep <davidg@nikhef.nl>
 *     NIKHEF Amsterdam, the Netherlands
 *
 *  2003-2007
 *     Martijn Steenbakkers <martijn@nikhef.nl>
 *     Gerben Venekamp <venekamp@nikhef.nl>
 *     Oscar Koeroo <okoeroo@nikhef.nl>
 *     David Groep <davidg@nikhef.nl>
 *     NIKHEF Amsterdam, the Netherlands
 *
 */


/*!
    \file   lcmaps_db_read.h
    \brief  header file for LCMAPS database structure
    \author Martijn Steenbakkers for the EU DataGrid.

    This header contains the declarations of the LCMAPS database structure

    \internal
*/

#ifndef LCMAPS_DB_READ_H
#define LCMAPS_DB_READ_H

/******************************************************************************
                             Include header files
******************************************************************************/
#include "lcmaps_defines.h"

/******************************************************************************
                               Type definitions
******************************************************************************/
/*!
    \struct  lcmaps_db_entry_s
    \brief   LCMAPS data base element structure
    \internal
*/
/*!
    \typedef lcmaps_db_entry_t
    \brief   type of LCMAPS data base element
    \internal
*/
typedef struct lcmaps_db_entry_s
{
    char                        pluginname[LCMAPS_MAXPATHLEN+1]; /*!< Name of authorization plugin/module */
    char                        pluginargs[LCMAPS_MAXARGSTRING+1]; /*!< Argument list to be passed to authorization plugin/module */
    struct lcmaps_db_entry_s *  next;  /*!< handle to next db element */
}
lcmaps_db_entry_t;

#endif /* LCMAPS_DB_READ_H */

/******************************************************************************
CVS Information:
    $Source: /srv/home/dennisvd/svn/mw-security/lcmaps/interface/lcmaps_db_read.h,v $
    $Date: 2011-03-04 21:55:13 +0100 (Fri, 04 Mar 2011) $
    $Revision: 14868 $
    $Author: dennisvd $
******************************************************************************/

==> lcmaps_1.6.6.orig.tar.gz: lcmaps-1.6.6/interface/lcmaps_db_read.h <==
/**
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010. 
 * See http://www.eu-egee.org/partners/ for details on the copyright
 * holders.  
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 *
 *  Authors:
 *  2009-
 *     Oscar Koeroo <okoeroo@nikhef.nl>
 *     Mischa Sall\'e <msalle@nikhef.nl>
 *     David Groep <davidg@nikhef.nl>
 *     NIKHEF Amsterdam, the Netherlands
 *     <grid-mw-security@nikhef.nl> 
 *
 *  2007-2009
 *     Oscar Koeroo <okoeroo@nikhef.nl>
 *     David Groep <davidg@nikhef.nl>
 *     NIKHEF Amsterdam, the Netherlands
 *
 *  2003-2007
 *     Martijn Steenbakkers <martijn@nikhef.nl>
 *     Gerben Venekamp <venekamp@nikhef.nl>
 *     Oscar Koeroo <okoeroo@nikhef.nl>
 *     David Groep <davidg@nikhef.nl>
 *     NIKHEF Amsterdam, the Netherlands
 *
 */


/*!
    \file   lcmaps_db_read.h
    \brief  header file for LCMAPS database structure
    \author Martijn Steenbakkers for the EU DataGrid.

    This header contains the declarations of the LCMAPS database structure

    \internal
*/

#ifndef LCMAPS_DB_READ_H
#define LCMAPS_DB_READ_H

/******************************************************************************
                             Include header files
******************************************************************************/
#include "lcmaps_defines.h"

/******************************************************************************
                               Type definitions
******************************************************************************/
/*!
    \struct  lcmaps_db_entry_s
    \typedef lcmaps_db_entry_t
    \brief   LCMAPS database element structure type
    \internal
*/
typedef struct lcmaps_db_entry_s
{
    char                        pluginname[LCMAPS_MAXPATHLEN+1]; /*!< Name of authorization plugin/module */
    char                        pluginargs[LCMAPS_MAXARGSTRING+1]; /*!< Argument list to be passed to authorization plugin/module */
    struct lcmaps_db_entry_s *  next;  /*!< handle to next db element */
}
lcmaps_db_entry_t;

#endif /* LCMAPS_DB_READ_H */

/******************************************************************************
CVS Information:
    $Source: /srv/home/dennisvd/svn/mw-security/lcmaps/interface/lcmaps_db_read.h,v $
    $Date: 2015-02-02 11:46:42 +0100 (Mon, 02 Feb 2015) $
    $Revision: 18216 $
    $Author: msalle $
******************************************************************************/
